# EDMS Admin Plugin

## Overview
The EDMS Admin Plugin is a comprehensive administrative control panel for system management and monitoring. It provides administrators with tools to manage users, monitor system resources, track file operations, manage backups, and maintain system security.

## Features

### User Management
- View and manage connected users
- Monitor user sessions and activities
- Send messages to connected users
- Disconnect users when needed
- Track user statistics and login history

### Department Management
- Create and manage departments
- Monitor department activities
- Force synchronization for specific departments
- Track department-specific statistics

### System Monitoring
- Real-time CPU, memory, and disk usage monitoring
- Network bandwidth tracking
- Application statistics
- System uptime monitoring
- Active session tracking

### File System Management
- Monitor file system statistics
- Track total files, sizes, and file types
- Storage health monitoring
- Hot folder monitoring
- File integrity verification
- Database consistency checks

### Network Monitoring
- Bandwidth usage tracking
- Active transfer monitoring
- Peer health monitoring
- Network status reporting
- Transfer speed and progress tracking

### Backup Management
- Automated and manual backup creation
- Multiple backup location support
- Backup verification
- Retention policy management
- Backup status monitoring
- Configurable backup schedules

### Security Features
- Screen lock configuration
- Authentication settings
- Session management
- Security status monitoring
- Active session termination
- Security policy enforcement

### Maintenance Tools
- Automated file cleanup
- Database optimization
- Data integrity verification
- System health checks
- Log management
- Storage fragmentation analysis

### Activity Monitoring
- User activity logging
- Real-time session monitoring
- Statistical analysis
- Detailed activity reports
- Performance metrics

## Installation

1. Place the plugin files in your EDMS plugins directory
2. Restart EDMS application
3. The Admin Control Panel will be available in the plugins menu


## Configuration

The plugin stores its configuration in the application settings. Key configuration areas include:

- Backup locations and schedules
- Security policies
- Maintenance schedules
- Monitoring preferences
- Log retention policies

## Usage

### Accessing the Control Panel
1. Open EDMS
2. Navigate to the plugins menu
3. Select "Admin Control Panel"

### Common Tasks

#### User Management
```
1. Select the "Connected Users" tab
2. View active users and their status
3. Use action buttons to manage users
```

#### Backup Operations
```
1. Navigate to the "Maintenance" tab
2. Select "Create Backup"
3. Choose backup location and options
4. Monitor backup progress
```

#### System Monitoring
```
1. Select the "System Monitor" tab
2. View real-time system statistics
3. Monitor resource usage
```

## Logging

The plugin maintains detailed logs of all operations:
- Location: `[LOCALAPPDATA]/ViozdocTracker/logs/admin.log`
- Log rotation: 90 days
- Configurable log levels

## Security

The plugin implements several security measures:
- Session monitoring
- Authentication requirements
- Activity logging
- Access control
- Secure communication

## Troubleshooting

Common issues and solutions:

1. **Connection Issues**
   - Verify network connectivity
   - Check firewall settings
   - Confirm port availability

2. **Backup Failures**
   - Verify write permissions
   - Check available storage space
   - Review backup logs

3. **Performance Issues**
   - Monitor system resources
   - Check log files for errors
   - Verify database optimization

## Support

For technical support:
- Check the log files
- Review documentation
- Contact system administrator
- Submit bug reports with log files


## License

Copyright Vioz Technologies 2025

## Version History

- 1.0: Initial release
  - Basic administrative features
  - User management
  - System monitoring

## Credits

Developed by Vioz Technologies
